@@ -29,13 +29,17 @@ class async_client:
     """The asynchronous idevision wrapper client."""
 
     def __init__(
-        self, token: typing.Union[str, None] = None, *, retry: typing.Optional[int] = 5
+        self,
+        token: typing.Union[str, None] = None,
+        *,
+        retry: typing.Optional[int] = 5,
+        url: str = "https://idevision.net/api/",
     ):
         self.token = token
 
         self.retry = int(retry)
 
-        self.base_url = "https://idevision.net/api/"
+        self.base_url = url.strip("/") + "/"
 
     async def _request(self, method: str, url: str, **kwargs):
         headers = kwargs.pop("headers", {})
